pub struct BabbageScript(/* private fields */);Implementations
Sourceimpl BabbageScript
impl BabbageScript
Sourcepub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes
- This type type supports encoding preservation so this will preserve round-trip CBOR formats.
- If created from scratch the CBOR will be canonical.
Sourcepub fn to_canonical_cbor_bytes(&self) -> Vec<u8> ⓘ
pub fn to_canonical_cbor_bytes(&self) -> Vec<u8> ⓘ
- Serialize this type to CBOR bytes using canonical CBOR encodings
Sourcepub fn from_cbor_bytes(cbor_bytes: &[u8]) -> Result<BabbageScript, JsError>
pub fn from_cbor_bytes(cbor_bytes: &[u8]) -> Result<BabbageScript, JsError>
- Create this type from CBOR bytes
Sourcepub fn to_cbor_hex(&self) -> String
pub fn to_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes encoded as a hex string (useful for working with CIP30).
- This type type supports encoding preservation so this will preserve round-trip CBOR formats.
- If created from scratch the CBOR will be canonical.
Sourcepub fn to_canonical_cbor_hex(&self) -> String
pub fn to_canonical_cbor_hex(&self) -> String
- Serialize this type to CBOR bytes using canonical CBOR encodings as hex bytes
Sourcepub fn from_cbor_hex(cbor_bytes: &str) -> Result<BabbageScript, JsError>
pub fn from_cbor_hex(cbor_bytes: &str) -> Result<BabbageScript, JsError>
- Create this type from the CBOR bytes encoded as a hex string.
- This is useful for interfacing with CIP30
Sourceimpl BabbageScript
impl BabbageScript
Sourceimpl BabbageScript
impl BabbageScript
pub fn new_native(script: &NativeScript) -> Self
pub fn new_plutus_v1(script: &PlutusV1Script) -> Self
pub fn new_plutus_v2(script: &PlutusV2Script) -> Self
pub fn kind(&self) -> BabbageScriptKind
pub fn as_native(&self) -> Option<NativeScript>
pub fn as_plutus_v1(&self) -> Option<PlutusV1Script>
pub fn as_plutus_v2(&self) -> Option<PlutusV2Script>